@@ -1,4 +1,4 @@
-# Copyright 2016-2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2016-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -21,7 +21,7 @@ import threading
 from reahl.tofu import scenario, expected, Fixture, temp_file_with, uses
 from reahl.tofu.pytestsupport import with_fixtures
 
-from reahl.webdev.tools import XPath
+from reahl.browsertools.browsertools import XPath
 
 from reahl.sqlalchemysupport import Session
 from reahl.webdeclarative.webdeclarative import PersistedFile
