@@ -1,4 +1,4 @@
-# Copyright 2015-2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2015-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -21,8 +21,8 @@ from sqlalchemy import Column, String, Integer
 from reahl.tofu import scenario, Fixture, uses, expected
 from reahl.tofu.pytestsupport import with_fixtures
 
-from reahl.webdev.tools import XPath, Browser
-from reahl.webdev.tools import WidgetTester
+from reahl.browsertools.browsertools import XPath, Browser
+from reahl.browsertools.browsertools import WidgetTester
 from reahl.component.modelinterface import exposed, Field, BooleanField, Event, Choice, ChoiceField,\
     MultiChoiceField, IntegerField, Action
 from reahl.component.exceptions import DomainException
