@@ -1,4 +1,4 @@
-# Copyright 2019, 2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2019, 2020, 2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -27,7 +27,7 @@ from reahl.web.fw import Widget
 from reahl.web.ui import Form, ButtonInput, TextInput, FormLayout, PrimitiveInput, HTMLElement, Div
 from reahl.web_dev.fixtures import WebFixture
 from reahl.web_dev.inputandvalidation.test_input import SimpleInputFixture
-from reahl.webdev.tools import Browser, XPath
+from reahl.browsertools.browsertools import Browser, XPath
 from reahl.sqlalchemysupport_dev.fixtures import SqlAlchemyFixture
 from reahl.sqlalchemysupport import Base, Session
 
