@@ -1,4 +1,4 @@
-# Copyright 2018, 2019, 2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2018-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -24,7 +24,7 @@ from reahl.tofu import Fixture, scenario, uses
 from reahl.tofu.pytestsupport import with_fixtures
 
 from reahl.web_dev.fixtures import WebFixture
-from reahl.webdev.tools import XPath
+from reahl.browsertools.browsertools import XPath
 from reahl.web.fw import Widget
 from reahl.web.ui import Form, Div, SelectInput, Label, P, RadioButtonSelectInput, CheckboxSelectInput, \
     CheckboxInput, ButtonInput, TextInput, FormLayout
